/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | www.openfoam.com
     \\/     M anipulation  |
-------------------------------------------------------------------------------
    Copyright (C) 2014-2016 OpenFOAM Foundation
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "general.H"
#include "addToRunTimeSelectionTable.H"

// * * * * * * * * * * * * * * Static Data Members * * * * * * * * * * * * * //

namespace Foam
{
namespace relativeVelocityModels
{
    defineTypeNameAndDebug(general, 0);
    addToRunTimeSelectionTable(relativeVelocityModel, general, components); 
}
}


// * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //

Foam::relativeVelocityModels::general::general
(
    const twoPhaseMixtureThermo& mixture,
    const fvMesh& mesh
)
:
    relativeVelocityModel(mixture, mesh),
    a_("a", dimless, optionalSubDict(type() + "Coeffs")),
    a1_("a1", dimless, optionalSubDict(type() + "Coeffs")),
    V0_("V0", dimVelocity, optionalSubDict(type() + "Coeffs")),
    residualAlpha_("residualAlpha", dimless, optionalSubDict(type() + "Coeffs")),
    rho0_("rho0",dimDensity,1)
{}


// * * * * * * * * * * * * * * * * Destructor  * * * * * * * * * * * * * * * //

Foam::relativeVelocityModels::general::~general()
{}


// * * * * * * * * * * * * * * Member Functions  * * * * * * * * * * * * * * //

void Foam::relativeVelocityModels::general::correct()
{
    volScalarField betac(max(1-alphad_, scalar(0))*rhoc_);
    volScalarField betad(max(1-alphac_, scalar(0))*rhod_);

    Udc_ =  V0_ *
            (
                exp(-a_*max(alphad_ - residualAlpha_, scalar(0)))
                - exp(-a1_*max(alphad_ - residualAlpha_, scalar(0)))
            );
    Udm_ = betac / rho() * Udc_;
    Ucm_ = - betad / rho() * Udc_;
}


// ************************************************************************* //
