/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | www.openfoam.com
     \\/     M anipulation  |
-------------------------------------------------------------------------------
    Copyright (C) 2014-2016 OpenFOAM Foundation
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::relativeVelocityModel

Description

SourceFiles
    relativeVelocityModel.C

\*---------------------------------------------------------------------------*/

#ifndef relativeVelocityModel_H
#define relativeVelocityModel_H

#include "fvCFD.H"
#include "dictionary.H"
#include "twoPhaseMixtureThermo.H"
#include "runTimeSelectionTables.H"
#include "rhoThermo.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

/*---------------------------------------------------------------------------*\
                         Class relativeVelocityModel Declaration
\*---------------------------------------------------------------------------*/

class relativeVelocityModel
:
    public IOdictionary
{
    // Private Member Functions

        //- Return the list of patchFieldTypes for Udm derived from U
        wordList UdmPatchFieldTypes() const;

        //- No copy construct
        relativeVelocityModel(const relativeVelocityModel&) = delete;

        //- No copy assignment
        void operator=(const relativeVelocityModel&) = delete;


protected:

    // Protected data

        //- Mixture properties
        const twoPhaseMixtureThermo& mixture_;

        //- Reference to fvMesh
        const fvMesh& mesh_;

        //- Name of the continuous phase
        // const word continuousPhaseName_;

        //- Continuous phase fraction
        const volScalarField& alphac_;

        //- Dispersed phase fraction
        const volScalarField& alphad_;

        //- Continuous density
        const volScalarField& rhoc_;

        //- Dispersed density
        const volScalarField& rhod_;

        //- Dispersed diffusion velocity
        mutable volVectorField Udm_;

        mutable volVectorField Udc_;

        mutable volVectorField Ucm_;

public:

    //- Runtime type information
    TypeName("relativeVelocityModel");

    //- Declare runtime constructor selection table
    declareRunTimeSelectionTable
    (
        autoPtr,
        relativeVelocityModel,
        components,
        (
            const twoPhaseMixtureThermo& mixture,
            const fvMesh& mesh
        ),
        (mixture, mesh)
    );


    // Constructors

        //- Construct from components
        relativeVelocityModel
        (
            const twoPhaseMixtureThermo& mixture,
            const fvMesh& mesh
        );


    // Selector
    static autoPtr<relativeVelocityModel> New
    (
        const twoPhaseMixtureThermo& mixture,
        const fvMesh& mesh
    );


    //- Destructor
    virtual ~relativeVelocityModel() = default;


    // Member Functions
    
        //- Return the mixture mean density
        tmp<volScalarField> rho() const;

        //- Return the diffusion velocity of the dispersed phase
        const volVectorField& Udm() const
        {
            return Udm_;
        }

        const volVectorField& Ucm() const
        {
            return Ucm_;
        }

        const volVectorField& Udc() const
        {
            return Udc_;
        }

        //- Return the stress tensor due to the phase transport
        tmp<volSymmTensorField> tauDm() const;

        //- Update the diffusion velocity
        virtual void correct()
        {}
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
