/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | www.openfoam.com
     \\/     M anipulation  |
-------------------------------------------------------------------------------
    Copyright (C) 2014-2017 OpenFOAM Foundation
    Copyright (C) 2019-2021 OpenCFD Ltd.
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "relativeVelocityModel.H"
#include "rhoThermo.H"

/*---------------------------------------------------------------------------*/

Foam::autoPtr<Foam::relativeVelocityModel> 
Foam::relativeVelocityModel::New
(
    const twoPhaseMixtureThermo& mixture,
    const fvMesh& mesh
)
{
    const IOdictionary dict
    (
        IOobject
        (
            "driftFluxProperties",
            mesh.time().constant(),
            mesh,
            IOobject::MUST_READ,
            IOobject::NO_WRITE,
            false // Do not register
        )
    );

    const word modelType(dict.get<word>("relativeVelocityModel"));

    Info<< "Selecting relative velocity model " << modelType << endl;

    auto* ctorPtr = componentsConstructorTable(modelType);

    if (!ctorPtr)
    {
        FatalIOErrorInLookup
        (
            dict,
            "relativeVelocityModel",
            modelType,
            *componentsConstructorTablePtr_
        ) << abort(FatalIOError);
    }

    return autoPtr<relativeVelocityModel>(ctorPtr(mixture, mesh));
}

// ************************************************************************* //
